# LLMConf

[![PyPI](https://img.shields.io/pypi/v/llmconf)](https://pypi.org/project/llmconf/)

LLMConf unifies the loading and generation configurations of various LLM backends (e.g. `openai`, `transformers`), simplifying parameter control for experiments and testing.

> [!Note]
> This project also serves as a practical exercise for learning Python project development skills.
